package MT::Plugin::EntityRefButton;

use strict;
use MT::Plugin;
@MT::Plugin::EntityRefButton::ISA = qw( MT::Plugin );

use vars qw( $VERSION $PLUGIN_NAME );
$PLUGIN_NAME = 'EntityRefButton';
$VERSION = '0.0.3';

use MT;

my $plugin = MT::Plugin::EntityRefButton->new({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => '<MT_TRANS phrase=\'This plugin adds a convert button to the entry body and the extended body fields on the edit entry screen, which converts special characters to character entity references.\'>',
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.gr.jp/',
    doc_link => 'http://labs.m-logic.jp/plugins/entityrefbutton/docs/entityrefbutton.html',
    l10n_class => 'EntityRefButton::L10N',
});
MT->add_plugin($plugin);
MT->add_callback('MT::App::CMS::AppTemplateSource.edit_entry', 9, $plugin, sub { transform('edit_entry', @_) });
MT->add_callback('MT::App::CMS::AppTemplateSource.bm_entry', 9, $plugin, sub { transform('bm_entry', @_) });

my %BUTTONS = (
	       edit_entry => [
			      # body
			      {
			       pattern_s => <<'PATTERN_END'
        write('<img title="<MT_TRANS phrase="Quote">" onclick="return formatStr(document.entry_form.text, \'blockquote\')" src="<TMPL_VAR NAME=STATIC_URI>images/formatting-icons/quote.gif" alt="<MT_TRANS phrase="Quote">" width="26" height="19" />');
PATTERN_END
,
			       pattern_e => '\s+\}\n\}',
			       replacement => <<'REPLACEMENT_END'
        write('<img title="_BUTTON_LABEL_" onclick="return convertToCharEntityRef(document.entry_form.text)" src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/formatting-icons/ref.gif" alt="_BUTTON_LABEL_" width="26" height="19" />');
REPLACEMENT_END
,
			      },
			      # extended body
			      {
			       pattern_s => <<'PATTERN_END'
        write('<img title="<MT_TRANS phrase="Quote">" onclick="return formatStr(document.entry_form.text_more, \'blockquote\')" src="<TMPL_VAR NAME=STATIC_URI>images/formatting-icons/quote.gif" alt="<MT_TRANS phrase="Quote">" width="26" height="19" />');
PATTERN_END
,
			       pattern_e => '\s+\}\n\}',
			       replacement => <<'REPLACEMENT_END'
        write('<img title="_BUTTON_LABEL_" onclick="return convertToCharEntityRef(document.entry_form.text_more)" src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/formatting-icons/ref.gif" alt="_BUTTON_LABEL_" width="26" height="19" />');
REPLACEMENT_END
			      },
			     ],
	       bm_entry => [
			    # body
			    {
			     pattern_s => <<'PATTERN_END'
        write('<a title="<MT_TRANS phrase="Quote">" href="#" onclick="return formatStr(document.entry_form.text, \'blockquote\')"><img src="<TMPL_VAR NAME=STATIC_URI>images/html-quote.gif" alt="<MT_TRANS phrase="Quote">" width="22" height="16" /></a>');
PATTERN_END
,
			     pattern_e => '\s+\}\n\}',
			     replacement => <<'REPLACEMENT_END'
        write('<a title="_BUTTON_LABEL_" href="#" onclick="return convertToCharEntityRef(document.entry_form.text)"><img src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/html-ref.gif" alt="_BUTTON_LABEL_" width="22" height="16" /></a>');
REPLACEMENT_END
,
			    },
			    # extended body
			    {
			     pattern_s => <<'PATTERN_END'
        write('<a title="<MT_TRANS phrase="Quote">" href="#" onclick="return formatStr(document.entry_form.text_more, \'blockquote\')"><img src="<TMPL_VAR NAME=STATIC_URI>images/html-quote.gif" alt="<MT_TRANS phrase="Quote">" width="22" height="16" /></a>');
PATTERN_END
,
			     pattern_e => '\s+\}\n\}',
			     replacement => <<'REPLACEMENT_END'
        write('<a title="_BUTTON_LABEL_" href="#" onclick="return convertToCharEntityRef(document.entry_form.text_more)"><img src="<TMPL_VAR NAME=STATIC_URI>plugins/EntityRefButton/images/html-ref.gif" alt="_BUTTON_LABEL_" width="22" height="16" /></a>');
REPLACEMENT_END
,
			    },
			   ],
	      );


sub instance { $plugin; }

sub transform {
  my $template_name = shift;
  my ($eh, $app, $tmpl) = @_;
  add_script($template_name, $eh, $app, $tmpl);
  add_convert_button($template_name, $eh, $app, $tmpl);
}

sub add_script {
  my $template_name = shift;
  my ($eh, $app, $tmpl) = @_;
  # insert javascript
  my $script = <<'SCRIPT';
function convertToCharEntityRef(e) {
    if(!canFormat) return;
    var str = getSelected(e);
    if(str) {
        str = str.replace(/&/g, "&amp;");
        str = str.replace(/ /g, "&nbsp;");
        str = str.replace(/</g, "&lt;");
        str = str.replace(/>/g, "&gt;");
        str = str.replace(/"/g, "&quot;");
        setSelection(e, str);
    }
    return false;
}

SCRIPT
  $$tmpl =~ s!(\n\n)(//-->\n</script>)!$1$script$2!is;
}

sub add_convert_button {
  my $template_name = shift;
  my ($eh, $app, $tmpl) = @_;
  # translate button's label
  my $alt_str = $plugin->translate('Convert to character entity reference');
  my $entries = $BUTTONS{$template_name};
  foreach my $item (@$entries) {
    my $pattern_s = $item->{pattern_s};
    my $pattern_e = $item->{pattern_e};
    my $replacement = $item->{replacement};
    $replacement =~ s!_BUTTON_LABEL_!$alt_str!isg;
    $$tmpl =~ s!(\Q$pattern_s\E)($pattern_e)!$1$replacement$2!is;
  }
}


1;

__END__
